@@ -1,5 +1,5 @@
 """This is a simple module to print the data items within a nested list"""
-def print_lol(items,level):
+def print_lol(items,level=0):
     for each_item in items:
         if isinstance(each_item, list):
             print_lol(each_item,level+1)
